# Structural Tension Chart Recording Instructions

This document provides a quick guide on how to update and record progress on the structural tension charts created for the `coaia-sequential-thinker` testing.

## Chart IDs from the MCP : "CoAiA-Testing-Charts"

*   **Main Testing Chart (CoAiA-Testing-Charts):** `chart_1757913836964`
*   **Action Step Chart (Integrate and test `initiate_sequential_thinking` tool):** `chart_1757913841767`



## What we want :

* That each step has an observations of what is intended from the tool
* Have the actual results in term of success or failure (ex.  lattice ran with error)
* If error, provide the error message and what you would have expected to have, think that another agent will make a new version based on what you will store in the action-step chart
* move to the next new action steps and repeat your testing and adding of observations and results


